# OzanArslan

This code implements a OzanArslan class that displays a scrolling text on the console screen. The text moves continuously to the right, and when it reaches the end of the screen, it wraps back to the beginning.

## Requirements

- Python 3.x

## Usage
To use the OzanArslan class, simply create an instance of the class and call its run() method:

```sh
from ozan.ozan import OzanArslan

ozan = OzanArslan()
ozan.run()
```


